@@ -1,3 +1,4 @@
+from __future__ import annotations
 from reamber.algorithms.analysis.playField import PlayField
 from reamber.algorithms.analysis.playField.parts.PFDrawable import PFDrawable
 
@@ -10,6 +11,7 @@ class PFDrawBpm(PFDrawable):
                  xOffset: int = 0,
                  yOffset: int = 0):
         """ Draws Bpms on the field
+
         :param decimalPlaces: The number of decimal places to display
         :param color: The color of the text
         :param xOffset: Padding from the right, useful if you have multiple text drawables overlapping
@@ -21,7 +23,7 @@ class PFDrawBpm(PFDrawable):
         self.color = color
 
     def draw(self, pf: PlayField) -> PlayField:
-        """[DRAW BPMs]"""
+        """ Refer to __init__ """
         for bpm in pf.m.bpms:
             txt = f"{bpm.bpm:.{self.decimalPlaces}f}"
             w, h = pf.canvasDraw.textsize(txt)
