@@ -1,3 +1,4 @@
+from __future__ import annotations
 from reamber.algorithms.analysis.playField import PlayField
 from reamber.algorithms.analysis.playField.parts.PFDrawable import PFDrawable
 
@@ -7,6 +8,7 @@ class PFDrawColumnLines(PFDrawable):
     def __init__(self,
                  color: str = "#2b2b2b"):
         """ Draws column lines, separating columns of notes
+
         :param color: The color of the column lines
         """
         self.color = color
@@ -14,7 +16,7 @@ class PFDrawColumnLines(PFDrawable):
         # so, we make it a PlayField prop
 
     def draw(self, pf: PlayField) -> PlayField:
-        """[DRAW COLUMN LINES]"""
+        """ Refer to __init__ """
 
         for colLine in range(1, pf.keys):  # Fencepost again, if key = 4, we draw on 1 2 3
             for w in range(pf.columnLineWidth):
