@@ -1,8 +1,4 @@
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING
-
-if TYPE_CHECKING:
-    from reamber.algorithms.analysis.playField.PlayField import PlayField
 
 
 class PFDrawable(ABC):
