@@ -9,6 +9,8 @@ class OsuTimingPointType:
 
 @dataclass
 class OsuTimingPointMeta:
+    """ Holds all metadata for every timing point object"""
+
     sampleSet: int = OsuSampleSet.AUTO
     sampleSetIndex: int = 0
     volume: int = 50
@@ -16,6 +18,7 @@ class OsuTimingPointMeta:
 
     @staticmethod
     def isTimingPoint(s: str) -> bool or None:
+        """ Checks whether if the string is a Timing Point/Bpm Obj"""
         t = s.split(",")
         if len(t) < 8:
             return None
@@ -23,6 +26,7 @@ class OsuTimingPointMeta:
 
     @staticmethod
     def isSliderVelocity(s: str) -> bool or None:
+        """ Checks whether if the string is a SV Point/SV Obj """
         t = s.split(",")
         if len(t) < 8:
             return None
