@@ -4,6 +4,4 @@ from dataclasses import dataclass
 
 @dataclass
 class SMRollObj(HoldObj):
-    STRING_HEAD: str = "4"
-    STRING_TAIL: str = "3"
     pass
