@@ -1,8 +1,9 @@
 from reamber.base.lists.notes.NoteList import NoteList
-from typing import List, Type
+from reamber.base.NoteObj import NoteObj
+from typing import List
 from abc import ABC
 
 
 class SMNoteList(NoteList, ABC):
-    def data(self) -> List[Type]: pass
+    def data(self) -> List[NoteObj]: pass
 
